@@ -160,9 +160,6 @@ sub execute {
     
     $self->{response_content} = $self->_execute_http_request();
 
-    # remove xmlns 
-    $self->{response_content}  =~ s/xmlns=["'][^"']+["']//;
-
     if ( $DEBUG ) {
         require Data::Dumper;
         print STDERR $self->{response_content};
